package com.hfkj.service.impl;

import com.hfkj.dao.BsDeviceMapper;
import com.hfkj.entity.BsDevice;
import com.hfkj.entity.BsDeviceExample;
import com.hfkj.service.BsDeviceService;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service("deviceService")
public class BsDeviceServiceImpl implements BsDeviceService {

    @Resource
    private BsDeviceMapper deviceMapper;

    @Override
    public void editDevice(BsDevice device) {
        if (device.getId() == null) {
            device.setCreateTime(new Date());
            device.setUpdateTime(new Date());
            device.setStatus(1);
            deviceMapper.insert(device);
        } else {
            device.setUpdateTime(new Date());
            deviceMapper.updateByPrimaryKey(device);
        }
    }

    @Override
    public BsDevice getDetailById(Long deviceId) {
        return deviceMapper.selectByPrimaryKey(deviceId);
    }

    @Override
    public List<BsDevice> getDeviceByMer(Long merId) {
        BsDeviceExample example = new BsDeviceExample();
        example.createCriteria().andMerIdEqualTo(merId).andStatusNotEqualTo(0);
        example.setOrderByClause("create_time desc");
        return deviceMapper.selectByExample(example);
    }

    @Override
    public List<BsDevice> getDeviceList(Map<String, Object> param) {
        BsDeviceExample example = new BsDeviceExample();
        BsDeviceExample.Criteria criteria = example.createCriteria().andStatusNotEqualTo(0);

        if (MapUtils.getInteger(param, "type") != null) {
            criteria.andTypeEqualTo(MapUtils.getInteger(param, "type"));
        }

        if (MapUtils.getLong(param, "companyId") != null) {
            criteria.andCompanyIdEqualTo(MapUtils.getLong(param, "companyId"));
        }

        if (MapUtils.getLong(param, "agentId") != null) {
            criteria.andAgentIdEqualTo(MapUtils.getLong(param, "agentId"));
        }

        if (MapUtils.getLong(param, "merId") != null) {
            criteria.andMerIdEqualTo(MapUtils.getLong(param, "merId"));
        }

        if (StringUtils.isNotBlank(MapUtils.getString(param, "deviceName"))) {
            criteria.andDeviceNameLike("%" + MapUtils.getString(param, "deviceName") + "%");
        }

        example.setOrderByClause("create_time desc");
        return deviceMapper.selectByExample(example);
    }
}
